@@ -1,28 +1,32 @@
-;;; ecb-jde.el: ECB JDE integrations
+;;; ecb-jde.el --- ECB JDE integrations
 
-;; Copyright (C) 2003 Jesper Nordenberg
-;; Copyright (C) 2003 Free Software Foundation, Inc.
-;; Copyright (C) 2003 Klaus Berndl <klaus.berndl@sdm.de>
+;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;;                           Klaus Berndl,
+;;                           Kevin A. Burton,
+;;                           Free Software Foundation, Inc.
 
-;; Author: Klaus Berndl <klaus.berndl@sdm.de>
+;; Author: Jesper Nordenberg <mayhem@home.se>
+;;         Klaus Berndl <klaus.berndl@sdm.de>
+;;         Kevin A. Burton <burton@openprivacy.org>
 ;; Maintainer: Klaus Berndl <klaus.berndl@sdm.de>
-;; Keywords: java, class, browser
+;;             Kevin A. Burton <burton@openprivacy.org>
+;; Keywords: browser, code, programming, tools
+;; Created: 2003
 
-;; This program is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
+;; This program is free software; you can redistribute it and/or modify it under
+;; the terms of the GNU General Public License as published by the Free Software
+;; Foundation; either version 2, or (at your option) any later version.
 
 ;; This program is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-;; more details.
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+;; FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+;; details.
 
-;; You should have received a copy of the GNU General Public License along
-;; with GNU Emacs; see the file COPYING. If not, write to the Free Software
+;; You should have received a copy of the GNU General Public License along with
+;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-jde.el,v 1.6 2003/07/18 12:55:08 berndl Exp $
+;; $Id: ecb-jde.el,v 1.8 2003/11/18 06:42:49 berndl Exp $
 
 ;;; Commentary:
 ;;
@@ -52,15 +56,18 @@
 
 (require 'ecb-util)
 (require 'ecb-layout)
+(require 'ecb-file-browser)
+(require 'ecb-method-browser)
 
 (defun ecb-jde-display-class-at-point ()
-  "Displays in the ECB-methods-buffer the contents \(methods, attributes
-etc...) of the class which contains the definition of the \"thing\" under
-point \(this can be a variablename, classname, methodname, attributename).
-This function needs the same requirements to work as the method-completion
-feature of JDE \(see `jde-complete-at-point')!. The source-file is searched
-first in `jde-sourcepath', then in `jde-global-classpath', then in $CLASSPATH,
-then in current-directory.
+  "Displays in the ECB-methods-buffer contents of class under point.
+This means displays the contents \(methods, attributes etc...) of the class
+which contains the definition of the \"thing\" under point \(this can be a
+variablename, classname, methodname, attributename). This function needs the
+same requirements to work as the method-completion feature of JDE \(see
+`jde-complete-at-point')!. The source-file is searched first in
+`jde-sourcepath', then in `jde-global-classpath', then in $CLASSPATH, then in
+current-directory.
 
 Works only for classes where the source-code \(i.e. the *.java-file) is
 available."
