@@ -1,10 +1,17 @@
-;;; ecb-layout.el --- layout for ECB
+;;; ecb-layout-defs.el --- layout definitions for ECB
 
-;; Copyright (C) 2000, 2001 Jesper Nordenberg, Klaus Berndl
+;; Copyright (C) 2000 - 2003 Jesper Nordenberg,
+;;                           Klaus Berndl,
+;;                           Kevin A. Burton,
+;;                           Free Software Foundation, Inc.
 
-;; Author: Klaus Berndl <klaus.berndl@sdm.de>
+;; Author: Jesper Nordenberg <mayhem@home.se>
+;;         Klaus Berndl <klaus.berndl@sdm.de>
+;;         Kevin A. Burton <burton@openprivacy.org>
 ;; Maintainer: Klaus Berndl <klaus.berndl@sdm.de>
-;; Keywords: java, class, browser
+;;             Kevin A. Burton <burton@openprivacy.org>
+;; Keywords: browser, code, programming, tools
+;; Created: 2002
 
 ;; This program is free software; you can redistribute it and/or modify it under
 ;; the terms of the GNU General Public License as published by the Free Software
@@ -19,7 +26,7 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-;; $Id: ecb-layout-defs.el,v 1.6 2003/07/18 12:55:08 berndl Exp $
+;; $Id: ecb-layout-defs.el,v 1.8 2003/11/18 06:42:49 berndl Exp $
 
 ;;; Commentary:
 ;;
@@ -866,7 +873,7 @@ little more place. This layout works best if it is contained in
   (select-window (next-window)))
 
 
-(defconst ecb-buildin-layouts (copy-list ecb-available-layouts)
+(defconst ecb-buildin-layouts (ecb-copy-list ecb-available-layouts)
   "All layouts defined until now.")
 
 (silentcomp-provide 'ecb-layout-defs)
